```
Language：GO  
GO version：1.22.5+  
```

# gep-demo-go

## 简介

gep-demo-go 是一个基于 Go 语言实现的测试demo，用于测试GEP相关产品接口的功能。

## 结构

```
├── README.md // 说明文档
├── cert // 证书文件
├── com.baofoo // GEP相关产品接口
│   ├── api
│   │   ├── exception // 异常处理
│   │   ├── request  // 请求参数
│   │   ├── response // 响应参数
│   │   ├── utils
│   │   │   ├── Config.go // 常量参数
│   │   │   ├── FileItem.go // 文件参数
│   │   │   └── RSAUtil.go // RSA加密工具
│   │   └── defaultClient.go // 默认客户端
│   └── example
│       ├── exchange // 兑换分发接口测试
│       └── vas // vcc接口测试
└── README.md // 说明文档
```

## 使用

1. 配置Config.go
   请求的证书及商户信息需要配置在Config.go，请根据实际情况修改。

2. 运行测试
   在example目录下，运行对应的测试文件即可。

### 示例

```
    request := request.BFRequest{}
    // Path接口路径
	request.Path = ""
    // Param是dataContent参数
	request.Param = map[string]string{
		"agentNo":       "5181200731000138828",
		"agentName":     "测试代理商",
		"agentType":     "1",
		"agentLevel":    "1",
		"agentParentNo": "5181200731000138828",
	}
    // 上传文件接口需传入FileItems，参考UploadFile.go
    request.FileItems = map[string]utils.FileItem{}

    // 下载文件或响应参数不需要解密时HasDownload = true
    //request.HasDownload = true

	client := defaultBFClient.NewDefaultBFClient()
	res, err := client.Execute(&request)
```

## 注意事项

- demo只实现公共请求和响应参数，具体业务参数请根据实际情况进行修改。
- demo仅供测试使用，您可以根据自己的业务需求进行对接对接。